Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleError ¶
func HandleError(ctx context.Context, obj types.Object, err error, recorder record.EventRecorder) (bool, reconcile.Result)
HandleError analyzes the given error and updates the object's conditions accordingly. It returns a boolean indicating whether the object's conditions were updated and a reconcile.Result that suggests whether to requeue the reconciliation and after what duration.
Types ¶
type BlockedError ¶
type CtrlError ¶
type CtrlError struct {
// contains filtered or unexported fields
}
func BlockedErrorf ¶
func RetryableErrorf ¶
func (*CtrlError) IsRetryable ¶
func (*CtrlError) RetryDelay ¶
type RetryableError ¶
type RetryableWithDelayError ¶
type RetryableWithDelayError interface {
error
RetryableError
RetryDelay() time.Duration
}
Click to show internal directories.
Click to hide internal directories.